@@ -15,35 +15,34 @@ from freighter import HTTPClientPool, Payload, UnaryClient
 
 from synnax.exceptions import QueryError
 from synnax.channel.payload import ChannelPayload
+from synnax.util.flatten import flatten
 
 
 class _Request(Payload):
-    keys: list[str] | None = None
+    keys_or_names: list[str] | None = None
     node_id: int | None = None
-    names: list[str] | None = None
 
 
 class _Response(Payload):
     channels: list[ChannelPayload] = []
-    not_found: list[str] = []
+    not_found: list[str] | None = []
 
 
 class ChannelRetriever(Protocol):
+    """Protocol for retrieving channel paylods from the cluster."""
+
     @overload
     def retrieve(
         self,
-        *,
-        key: str | None = None,
-        name: str | None = None,
+        key_or_name: str,
     ) -> ChannelPayload | None:
         ...
 
     @overload
     def retrieve(
         self,
-        *,
-        keys: list[str] | None = None,
-        names: list[str] | None = None,
+        key_or_name: str | tuple[str] | list[str],
+        *keys_or_names: str | tuple[str] | list[str],
         node_id: int | None = None,
         include_not_found: Literal[False] = False,
     ) -> list[ChannelPayload]:
@@ -52,9 +51,8 @@ class ChannelRetriever(Protocol):
     @overload
     def retrieve(
         self,
-        *,
-        keys: list[str] | None = None,
-        names: list[str] | None = None,
+        key_or_name: str | tuple[str] | list[str],
+        *keys_or_names: str | tuple[str] | list[str],
         node_id: int | None = None,
         include_not_found: Literal[True] = True,
     ) -> tuple[list[ChannelPayload], list[str]]:
@@ -63,16 +61,16 @@ class ChannelRetriever(Protocol):
     @overload
     def retrieve(
         self,
-        *,
-        key: str | None = None,
-        name: str | None = None,
-        keys: list[str] | None = None,
-        names: list[str] | None = None,
+        key_or_name: str | tuple[str] | list[str],
+        *keys_or_names: str | tuple[str] |  list[str],
         node_id: int | None = None,
         include_not_found: bool = False,
-    ) -> list[ChannelPayload] | tuple[
-        list[ChannelPayload], list[str]
-    ] | ChannelPayload | None:
+    ) -> (
+        tuple[list[ChannelPayload], list[str]]
+        | list[ChannelPayload]
+        | ChannelPayload
+        | None
+    ):
         ...
 
 
@@ -88,29 +86,27 @@ class ClusterChannelRetriever:
 
     def retrieve(
         self,
-        key: str | None = None,
-        name: str | None = None,
-        keys: list[str] | None = None,
-        names: list[str] | None = None,
+        key_or_name: str | list[str],
+        *keys_or_names: str | list[str],
         node_id: int | None = None,
         include_not_found: bool = False,
-    ) -> tuple[list[ChannelPayload], list[str]] | list[
-        ChannelPayload
-    ] | ChannelPayload | None:
-        single_key = key is not None
-        single_name = name is not None
-        req = _Request(
-            keys=[key] if single_key else keys,
-            names=[name] if single_name else names,
-            node_id=node_id,
-        )
+    ) -> (
+        tuple[list[ChannelPayload], list[str]]
+        | list[ChannelPayload]
+        | ChannelPayload
+        | None
+    ):
+        single = is_single(key_or_name, keys_or_names)
+        flat = flatten(key_or_name, *keys_or_names)
+
+        req = _Request(keys_or_names=flat, node_id=node_id)
         res, exc = self.client.send(self._ENDPOINT, req, _Response)
         if exc is not None:
             raise exc
         assert res is not None
-        if include_not_found is True:
-            return res.channels, res.not_found
-        if single_key or single_name:
+        if include_not_found == True:
+            return res.channels, res.not_found or list()
+        if single:
             if len(res.channels) == 1:
                 return res.channels[0]
             if len(res.channels) == 0:
@@ -120,60 +116,57 @@ class ClusterChannelRetriever:
 
 
 class CacheChannelRetriever:
-    retriever: ChannelRetriever
+    _retriever: ChannelRetriever
     channels: dict[str, ChannelPayload]
     names_to_keys: dict[str, str]
 
     def __init__(self, retriever: ChannelRetriever) -> None:
         self.channels = dict()
         self.names_to_keys = dict()
-        self.retriever = retriever
+        self._retriever = retriever
 
     def _(self) -> ChannelRetriever:
         return self
 
     def retrieve(
         self,
-        key: str | None = None,
-        name: str | None = None,
-        keys: list[str] | None = None,
-        names: list[str] | None = None,
+        key_or_name: str | list[str],
+        *keys_or_names: str | list[str],
         node_id: int | None = None,
         include_not_found: bool = False,
-    ) -> tuple[list[ChannelPayload], list[str]] | list[
-        ChannelPayload
-    ] | ChannelPayload | None:
+    ) -> (
+        tuple[list[ChannelPayload], list[str]]
+        | list[ChannelPayload]
+        | ChannelPayload
+        | None
+    ):
         if node_id is not None:
-            return self.retriever.retrieve(
-                node_id=node_id, include_not_found=include_not_found
+            return self._retriever.retrieve(
+                key_or_name,
+                *keys_or_names,
+                node_id=node_id,
+                include_not_found=include_not_found,
             )
 
-        keys, single_key = self._normalize(key, keys)
-        names, single_name = self._normalize(name,names)
-        keys_to_retrieve = list()
-        names_to_retrieve = list()
+        single = is_single(key_or_name, keys_or_names)
+        flat = flatten(key_or_name, *keys_or_names)
+
         results = list()
+        to_retrieve = list()
 
-        for name in names:
-            key = self.names_to_keys.get(name, None)
-            if key is not None:
-                keys.append(key)
-            else:
-                names_to_retrieve.append(name)
-
-        for key in keys:
+        for entry in flat:
+            key = self.names_to_keys.get(entry, entry)
             channel = self.channels.get(key, None)
             if channel is None:
-                keys_to_retrieve.append(key)
+                to_retrieve.append(key)
             else:
                 results.append(channel)
 
-        if len(keys_to_retrieve) == 0 and len(names_to_retrieve) == 0:
+        if len(to_retrieve) == 0:
             return results
 
-        retrieved, not_found = self.retriever.retrieve(
-            keys=keys_to_retrieve,
-            names=names_to_retrieve,
+        retrieved, not_found = self._retriever.retrieve(
+            *to_retrieve,
             include_not_found=True,
         )
 
@@ -182,15 +175,19 @@ class CacheChannelRetriever:
             self.names_to_keys[channel.name] = channel.key
             results.append(channel)
 
-        if include_not_found:
+        if include_not_found == True:
             return results, not_found
-        if single_key or single_name:
-            return None if len(results) == 0 else results[0]
+        if single:
+            if len(results) == 0:
+                return None
+            if len(results) == 1:
+                return results[0]
+            raise QueryError("multiple channels found")
         return results
 
-    def _normalize(self, key: str | None, keys: list[str] | None) -> tuple[list[str], bool]:
-        if key is not None:
-            return [key], True
-        if keys is None:
-            return [], False
-        return keys, False
+
+def is_single(
+    key_or_name: str | list[str], keys_or_names: tuple[str | list[str]]
+) -> bool:
+    """Determine if a list of keys or names is a single key or name."""
+    return isinstance(key_or_name, str) and len(keys_or_names) == 0
