@@ -52,13 +52,11 @@ class RowIngestionEngine:
         self.reader = reader
         self.client = client
         self.reader.set_chunk_size(self.get_chunk_size())
-        self.writer = self.client.new_writer(
-            start=start, keys=[ch.key for ch in channels]
-        )
+        self.writer = self.client.new_writer(start, [ch.key for ch in channels])
 
     def get_chunk_size(self):
         """Sum the density of all channels to determine the chunk size."""
-        return self.mem_limit // sum(ch.density for ch in self.channels)
+        return self.mem_limit // sum(ch.data_type.density for ch in self.channels)
 
     def run(self):
         """Run the ingestion engine."""
