@@ -13,7 +13,7 @@ from typing import Protocol, Iterator
 
 from pandas import DataFrame
 
-from .meta import ChannelMeta
+from synnax.io.meta import ChannelMeta
 
 
 class ReaderType(Enum):
@@ -138,7 +138,7 @@ class DataFrameWriter(Closer, Protocol):
     such as a Synnax cluster.
     """
 
-    def write(self, df: DataFrame):
+    def write(self, df: DataFrame) -> None | bool:
         """Writes the given dataframe to the buffer."""
         ...
 
